@@ -20,3 +20,11 @@ from jax_md import smap
 from jax_md import partition
 from jax_md import dataclasses
 from jax_md import nn
+from jax_md import interpolate
+from jax_md import util
+
+try:
+  # Attempt to load colab_tools if IPython is installed.
+  from jax_md import colab_tools
+except:
+  pass
